boundary_segments() returns the boundary segments that separate
administrative entities or borders with the Atlantic Ocean in the Azores.
boundary_segments_25N() returns the boundary segments in the meter-based projection PTRA08
/ UTM zone 25N, i.e. those boundary segments in the western-most part of the
archipelago: Ilha das Flores and Ilha do Corvo.
boundary_segments_26N() returns the boundary segments in the meter-based projection PTRA08
/ UTM zone 26N, i.e. those boundary segments in the Central and Eastern groups of
the archipelago.
boundary_segments(crs = laea_azores_proj())boundary_segments_25N()
boundary_segments_26N()
A simple features (sf) object with seven fields:
idAn unique UUID identifier for the segment.
id_at_rightIdentifier for the entity at the right side of the boundary.
id_at_leftIdentifier for the entity at the left side of the boundary.
is_confirmedBoundary segment whose acceptance by the parties has not yet been officially communicated.
boundary_typeBoundary type: land or coast.
boundary_levelBoundary level: administrative level.
lengthBoundary segment length in kilometers.
Coordinate reference system (CRS) passed on to
st_transform(). Defaults to a custom CRS centered on
the Azores, see laea_azores_proj() for more details. Other possible
options are "EPSG: 3035" for ETRS89-extended / LAEA Europe or
"EPSG:4326" for WGS 84.
boundary_segments()
boundary_segments_25N()
boundary_segments_26N()
Run the code above in your browser using DataLab