districts() returns the boundaries of districts (islands) in the Azores.
districts_25N() returns the districts in the meter-based projection PTRA08
/ UTM zone 25N, i.e. those districts in the western-most part of the
archipelago: Ilha das Flores and Ilha do Corvo.
districts_26N() returns the districts in the meter-based projection PTRA08
/ UTM zone 26N, i.e. those districts in the Central and Eastern groups of
the archipelago.
districts(crs = laea_azores_proj())districts_25N()
districts_26N()
A simple features (sf) object with six fields:
idAn unique identifier for the district. Follows the format
[DT][MN][FR]: DT is a two-digit id for the district, MN for the
municipality and FR for the district (freguesia in Portuguese).
districtName of the civil district.
municipalityName of municipality.
districtName of district, coincides with the name of the island.
areaDistrict area in hectares (ha).
perimeterDistrict perimeter in kilometers.
n_municipalitiesNumber of municipalities in the district.
n_parishesNumber of parishes in the district.
Coordinate reference system (CRS) passed on to
st_transform(). Defaults to a custom CRS centered on
the Azores, see laea_azores_proj() for more details. Other possible
options are "EPSG: 3035" for ETRS89-extended / LAEA Europe or
"EPSG:4326" for WGS 84.
districts()
districts_25N()
districts_26N()
Run the code above in your browser using DataLab