nuts() returns the boundaries of the Nomenclature of Territorial Units for
Statistics (NUTS).
nuts_25N() returns the NUTS boundaries in the meter-based projection PTRA08
/ UTM zone 25N, i.e. the NUTS area in the western-most part of the
archipelago: Ilha das Flores and Ilha do Corvo.
nuts_26N() returns the NUTS boundaries in the meter-based projection PTRA08
/ UTM zone 26N, i.e. the NUTS area in the Central and Eastern groups of
the archipelago.