Learn R Programming

CAOP.RAA.2024 (version 0.0.5)

parishes: Azorean civil administrative parishes

Description

parishes() returns the boundaries of civil parishes in the Azores.

parishes_25N() returns the parishes in the meter-based projection PTRA08 / UTM zone 25N, i.e. those parishes in the western-most part of the archipelago: Ilha das Flores and Ilha do Corvo.

parishes_26N() returns the parishes in the meter-based projection PTRA08 / UTM zone 26N, i.e. those parishes in the Central and Eastern groups of the archipelago.

Usage

parishes(crs = laea_azores_proj())

parishes_25N()

parishes_26N()

Value

A simple features (sf) object with six fields:

id

An unique identifier for the parish. Follows the format [DT][MN][FR]: DT is a two-digit id for the district, MN for the municipality and FR for the parish (freguesia in Portuguese).

parish

Name of the civil parish.

municipality

Name of municipality.

district

Name of district, coincides with the name of the island.

area

Parish area in hectares (ha).

perimeter

Parish perimeter in kilometers.

Arguments

crs

Coordinate reference system (CRS) passed on to st_transform(). Defaults to a custom CRS centered on the Azores, see laea_azores_proj() for more details. Other possible options are "EPSG: 3035" for ETRS89-extended / LAEA Europe or "EPSG:4326" for WGS 84.

Examples

Run this code
parishes()
parishes_25N()
parishes_26N()

Run the code above in your browser using DataLab